--- setup.py.orig	2021-12-01 11:09:36 UTC
+++ setup.py
@@ -61,7 +61,7 @@ setup(
     packages=find_packages(exclude=["tests"]),
     data_files=[
         (
-            "share/man/man1",
+            "man/man1",
             [
                 "doc/barman.1",
                 "doc/barman-cloud-backup.1",
@@ -73,7 +73,7 @@ setup(
                 "doc/barman-wal-restore.1",
             ],
         ),
-        ("share/man/man5", ["doc/barman.5"]),
+        ("man/man5", ["doc/barman.5"]),
     ],
     entry_points={
         "console_scripts": [



--- barman/config.py.orig	2021-12-01 11:09:36 UTC
+++ barman/config.py
@@ -661,8 +661,8 @@ class Config(object):
 
     CONFIG_FILES = [
         "~/.barman.conf",
-        "/etc/barman.conf",
-        "/etc/barman/barman.conf",
+        "%%PREFIX%%/etc/barman.conf",
+        "%%PREFIX%%/etc/barman/barman.conf",
     ]
 
     _QUOTE_RE = re.compile(r"""^(["'])(.*)\1$""")



--- setup.py.orig	2015-10-19 05:48:12 UTC
+++ setup.py
@@ -63,6 +63,12 @@ extra_link_args = []
 scripts = []
 defines = []
 
+if sys.platform.startswith('dragonfly') or \
+   sys.platform.startswith('freebsd'):
+    include_dirs = ['%%LOCALBASE%%/include/']
+    external_libraries = []
+    extra_link_args = ['%%LOCALBASE%%/lib/libportaudio.so']
+
 if sys.platform == 'darwin':
     defines += [('MACOSX', '1')]
     if mac_sysroot_path:
